﻿using System.Transactions;
using Microsoft.AspNetCore.Mvc;
using UnivateProperties_API.Model.Users;
using UnivateProperties_API.Repository;
using UnivateProperties_API.Repository.Users;

namespace User_API.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class AgentController : ControllerBase
    {
        private readonly IRepository<Agent> _Repo;

        public AgentController(IRepository<Agent> repo)
        {
            _Repo = repo;
        }

        [HttpGet]
        public IActionResult Get()
        {
            return new OkObjectResult(_Repo.GetAll());
        }

        [HttpGet("{id}")]
        public IActionResult Get(int id)
        {
            return new OkObjectResult(_Repo.Get(x => x.Id == id));
        }

        [HttpPost()]
        public IActionResult Post([FromBody] Agent agent)
        {
            using (var scope = new TransactionScope())
            {
                _Repo.Insert(agent);
                scope.Complete();
                return CreatedAtAction(nameof(Get), new { id = agent.Id }, agent);
            }
        }

        [HttpPut()]
        public IActionResult Put([FromBody] Agent agent)
        {
            if (agent != null)
            {
                using (var scope = new TransactionScope())
                {
                    _Repo.Update(agent);
                    scope.Complete();
                    return new OkResult();
                }
            }
            return new NoContentResult();
        }

        [HttpDelete("{id}")]
        public IActionResult Delete(int id)
        {
            _Repo.RemoveAtId(id);
            return new OkResult();
        }
    }
}
